@@ -1,4 +1,3 @@
-
 #
 # This program gives a combined electronic diary and time clock.
 # Copyright John Lines (john+taglog@paladyn.org) October 2001
@@ -92,7 +91,7 @@ frame .aboutBox.bot -relief raised -bd 1
 pack .aboutBox.bot -side bottom -fill both
 
 message .aboutBox.top.msg -width 4i -text \
- "About Taglog: This is version $version Copyright 2000 John Lines <john+taglog@paladyn.org>\nTaglog is Free Software, released under the terms of the GNU Public License.\nSee https://github.com/JohnLines/taglog/wiki for the taglog home page"
+ "About Taglog: This is version $version Copyright 2019 John Lines <john+taglog@paladyn.org>\nTaglog is Free Software, released under the terms of the GNU Public License.\nSee https://github.com/JohnLines/taglog/wiki for the taglog home page"
 
 pack .aboutBox.top.msg -side right -expand 1 -fill both -padx 3m -pady 3m
 
@@ -130,6 +129,14 @@ global num_today_actions history_win_depth current_win_depth
 global version
 global month year
 global debug
+global isAndroid
+
+
+set winwid 60
+
+#if {[winfo screenmmwidth .] > 100 } { set winwid 30 }
+if { $isAndroid } { set winwid 30 }
+
 #
 # Set up basic display structure
 #
@@ -178,6 +185,7 @@ menu .mBar.actions.m.e
 .mBar.actions.m.e add command -label [mc "Active Time Blocked"] -command activate_timeblocked
 .mBar.actions.m.e add command -label [mc "Archive Old Actions"] -command archiveOldActions
 .mBar.actions.m.e add command -label [mc "Update All Subtasks"] -command Update_all_subtasks
+.mBar.actions.m.e add command -label [mc "Display Periodic Actions"] -command displayPeriodicActions
 
 .mBar.actions.m add separator
 .mBar.actions.m add command -label [mc "Help"] -command "taghelp actions"
@@ -235,7 +243,9 @@ menu .mBar.help.m.h.p
 .mBar.help.m.h add separator
 .mBar.help.m.h add command -label [mc "Help"] -command "taghelp hint_help"
 
+# Normally only show this if debug is enabled, but for now show it all the time
 
+.mBar.help.m add command -label [mc "Debug"] -command "showDebug"
 
 pack .mBar.file .mBar.actions .mBar.projects .mBar.reports .mBar.contacts -side left
 pack .mBar.help -side right
@@ -248,7 +258,7 @@ if { $num_today_actions != 0 } {
 
 if { $display_prevday } {
 frame .prevday
-text .prevday.body -rel sunk -width 60 -height 15 -wrap word -yscrollcommand ".prevday.sb set"
+text .prevday.body -rel sunk -width $winwid -height 15 -wrap word -yscrollcommand ".prevday.sb set"
 scrollbar .prevday.sb -rel sunk -command ".prevday.body yview"
 pack .prevday.body -side right -in .prevday -fill both -expand 1
 pack .prevday.sb -side right -fill y -in .prevday
@@ -256,7 +266,7 @@ pack .prevday -fill both -expand 1
 }
 
 frame .preventries
-text .preventries.body -rel sunk -width 60 -height $history_win_depth -wrap word -yscrollcommand ".preventries.sb set" -state disabled
+text .preventries.body -rel sunk -width $winwid -height $history_win_depth -wrap word -yscrollcommand ".preventries.sb set" -state disabled
 scrollbar .preventries.sb -rel sunk -command ".preventries.body yview"
 pack .preventries.body -side right -in .preventries -fill both -expand 1
 pack .preventries.sb -side right -fill y -in .preventries
@@ -329,7 +339,7 @@ pack .actionbar
 
 frame .description
 frame .description.textf
-text .description.body -rel sunk -width 60 -height $current_win_depth \
+text .description.body -rel sunk -width $winwid -height $current_win_depth \
   -wrap word -yscrollcommand ".description.sb set"
 scrollbar .description.sb -rel sunk -command ".description.body yview"
 pack .description.body -side right -in .description.textf -expand 1 -fill both
@@ -422,3 +432,47 @@ eval $debugCommand
 
 }
 
+proc showDebug {} {
+	
+	global tcl_platform
+	
+	set info "Debug information\n"
+	append info "Platform " $tcl_platform(platform) "\nUser " $tcl_platform(user)
+	
+	
+	# These Variables are only available on Android
+	
+	if { [catch {package require Borg}]} {
+		# Borg package not available
+		set android_something "not available"
+#		puts "Not on android"
+	} else {
+		append info "\nAndroid user data directory " [borg osenvironment datadir]
+		append info "\nAndroid displaymetrics " [borg displaymetrics]
+		
+	}
+	
+	if { [info commands sdltk] ne "" } {
+		append info "\nRunning on android " [sdltk android]
+		append info "\nMaxroot width " [lindex [sdltk maxroot] 0] " height " [lindex [sdltk maxroot] 1]
+		append info "\nroot width " [lindex [sdltk root] 0] " height " [lindex [sdltk root] 1]
+		append info "\nsdltk  root size width " [lindex [sdltk root] 0] " height " [lindex [sdltk root] 1]
+	}
+	
+	toplevel .showdebug
+	wm title .showdebug "Debugging information"
+	
+	append info "\nGeometry of showdebug " [winfo geometry .showdebug]
+    append info "\nGeometry of . " [winfo geometry .]
+	append info "\nScreen name " [winfo screen .showdebug]
+	append info "\nScreen width " [winfo screenwidth .showdebug] " height " [winfo screenheight .showdebug]
+	append info "\nScreen mm width " [winfo screenmmwidth .] " height " [winfo screenmmwidth .]
+
+	
+	
+	
+	frame .showdebug.main -width 200
+	message .showdebug.info -text $info
+	
+	pack .showdebug.info .showdebug.main
+}
