@@ -281,6 +281,8 @@ foreach i $validStates {
 }
 actin_setup_field $w $winnum $mode Status actin_f_a($winnum,Status) $lw 40 selection actinput_status Pending $vStates $validStates
 
+actin_setup_field $w $winnum $mode Period actin_f_a($winnum,Period) $lw 40 string actinput_period ""
+
 actin_setup_field $w $winnum $mode Expected-cost actin_f_a($winnum,Expected-cost) $lw 40 string actinput_expected_cost ""
 
 actin_setup_field $w $winnum $mode Expected-time actin_f_a($winnum,Expected-time) $lw 40 selection actinput_expected_time "" [list "0:05" "0:10" "0:20" "0:30" "1:00" "2:00" "3:00" "4:00" "6:00" "8:00 (1 [mc day])" "12:00 (1.5 [mc days])" "16:00 (2 [mc days])" "24:00 (3 [mc days])" "40:00 (1 [mc week])"]  [list "0:05" "0:10" "0:20" "0:30" "1:00" "2:00" "3:00" "4:00" "6:00" "8:00" "12:00" "16:00" "24:00" "40:00"]
@@ -518,6 +520,7 @@ set action ""
  set action [tagappend $action Date $actin_f_a($winnum,Date)]
  set action [tagappend $action Priority $actin_f_a($winnum,Priority)]
  set action [tagappend $action Status $actin_f_a($winnum,Status)]
+ set action [tagappend $action Period $actin_f_a($winnum,Period)]
  set action [tagappend $action Expected-cost $actin_f_a($winnum,Expected-cost)]
  set action [tagappend $action Expected-time $actin_f_a($winnum,Expected-time)]
  set action [tagappend $action Expected-start-date $actin_f_a($winnum,Expected-start-date)]
@@ -591,7 +594,7 @@ set fn [tk_getSaveFile -defaultextension ".txt" ]
 }
 
 proc set_actsel_tests {} {
-global actsel_project actsel_st_any actsel_st_unclaimed actsel_st_pending actsel_st_active actsel_st_blocked actsel_st_delegated actsel_st_completed actsel_st_aborted actsel_showfields actsel_maxpriority actsel_expected_start actsel_expected_completed actsel_expected_start_test actsel_expected_completed_test actsel_filename actsel_id actsel_title
+global actsel_project actsel_st_any actsel_st_unclaimed actsel_st_pending actsel_st_active actsel_st_blocked actsel_st_delegated actsel_st_completed actsel_st_aborted actsel_st_periodic actsel_showfields actsel_maxpriority actsel_expected_start actsel_expected_completed actsel_expected_start_test actsel_expected_completed_test actsel_filename actsel_id actsel_title
 
 if {$actsel_project !=""} {
  set test [list Project == $actsel_project]
@@ -619,6 +622,10 @@ if {! $actsel_st_any } {
  if { $actsel_st_aborted } {
 	lappend status_list Aborted
 	}
+ if { $actsel_st_periodic } {
+	lappend status_list Periodic
+	}
+
  set test [list Status "-in" $status_list]
  lappend tests $test
 
@@ -702,6 +709,8 @@ foreach action $thisaction {
    set actin_f_a($winnum,Priority) [lindex $item 1]
  } elseif { [lindex $item 0] == "Status"} {
    set actin_f_a($winnum,Status) [lindex $item 1]
+ } elseif { [lindex $item 0] == "Period"} {
+   set actin_f_a($winnum,Period) [lindex $item 1]
  } elseif { [lindex $item 0] == "Expected-cost"} {
    set actin_f_a($winnum,Expected-cost) [lindex $item 1]
  } elseif { [lindex $item 0] == "Expected-time"} {
@@ -762,7 +771,7 @@ if { $tagname == $selector } {
 
 
 proc fillactwindow {} {
-global actsel_project actsel_st_any actsel_st_unclaimed actsel_st_pending actsel_st_active actsel_st_blocked actsel_st_delegated actsel_st_completed actsel_st_aborted actsel_showfields actsel_maxpriority actsel_expected_start actsel_expected_completed actsel_expected_start_test actsel_expected_completed_test actsel_filename actsel_sortby
+global actsel_project actsel_st_any actsel_st_unclaimed actsel_st_pending actsel_st_active actsel_st_blocked actsel_st_delegated actsel_st_completed actsel_st_aborted actsel_st_periodic actsel_showfields actsel_maxpriority actsel_expected_start actsel_expected_completed actsel_expected_start_test actsel_expected_completed_test actsel_filename actsel_sortby
 
 global actionsfilename allact
  .actview.main.body delete 1.0 end
@@ -1259,7 +1268,7 @@ foreach item $action {
 }
 
 proc actSelect { okcommand } {
-global actsel_project actsel_st_any actsel_st_unclaimed actsel_st_pending actsel_st_active actsel_st_blocked actsel_st_delegated actsel_st_completed actsel_st_aborted actsel_maxpriority actsel_showfields actsel_filename actsel_filenames actsel_expected_start actsel_expected_completed actsel_expected_start_test actsel_expected_completed_test actsel_id actsel_title actsel_projstat actsel_sortby
+global actsel_project actsel_st_any actsel_st_unclaimed actsel_st_pending actsel_st_active actsel_st_blocked actsel_st_delegated actsel_st_completed actsel_st_aborted actsel_st_periodic actsel_maxpriority actsel_showfields actsel_filename actsel_filenames actsel_expected_start actsel_expected_completed actsel_expected_start_test actsel_expected_completed_test actsel_id actsel_title actsel_projstat actsel_sortby
 
 proc setupActselProjMenu { varname index op } {
 global actsel_projstat
@@ -1314,7 +1323,8 @@ checkbutton .actsel.tagselect.status.blocked -text [mc Blocked] -variable actsel
 checkbutton .actsel.tagselect.status.delegated -text [mc Delegated] -variable actsel_st_delegated
 checkbutton .actsel.tagselect.status.completed -text [mc Completed] -variable actsel_st_completed
 checkbutton .actsel.tagselect.status.aborted -text [mc Aborted] -variable actsel_st_aborted
-pack .actsel.tagselect.status.l .actsel.tagselect.status.any .actsel.tagselect.status.unclaimed .actsel.tagselect.status.pending .actsel.tagselect.status.active .actsel.tagselect.status.blocked .actsel.tagselect.status.delegated .actsel.tagselect.status.completed .actsel.tagselect.status.aborted -side left -in .actsel.tagselect.status
+checkbutton .actsel.tagselect.status.periodic -text [mc Periodic] -variable actsel_st_periodic
+pack .actsel.tagselect.status.l .actsel.tagselect.status.any .actsel.tagselect.status.unclaimed .actsel.tagselect.status.pending .actsel.tagselect.status.active .actsel.tagselect.status.blocked .actsel.tagselect.status.delegated .actsel.tagselect.status.completed .actsel.tagselect.status.aborted .actsel.tagselect.status.periodic -side left -in .actsel.tagselect.status
 pack .actsel.tagselect.status
 
 frame .actsel.tagselect.priority
@@ -1513,6 +1523,7 @@ for { set i 1 } { $i <= $num_today_actions } { incr i } {
 proc setcurrentAction { id } {
 global currentAction currentProject activeactions currentActionTitle
 
+
 if { $id < 0 } {
   set currentAction ""
   set currentActionTitle ""
@@ -1530,6 +1541,56 @@ foreach entry $activeactions {
 }
 }
 
+proc setcurrentPeriodicAction { id } {
+global currentAction currentProject currentActionTitle allact
+
+# Note that the format of periodicActions as generated here is a full
+# subset of allact - rather than just a a list of id project and title
+# so need to deal with this when setting up
+
+
+donext ""
+
+if { $id < 0 } {
+  set currentAction ""
+  set currentActionTitle ""
+  return
+}
+set currentAction $id
+set currentProject ""
+
+foreach action $allact {
+ foreach item $action {
+#   puts "item is $item"
+   if {( [lindex $item 0] == "Status" ) && ([lindex $item 1] == "Periodic" )} {
+# need to check if it has already been done - i.e. Completed during this period
+# but for now ..
+	lappend periodicActions $action
+        # 
+	}
+   }
+}
+
+# puts "periodicActions is $periodicActions"
+
+foreach entry $periodicActions {
+ set thisid [lindex $entry 0]
+#  puts "thisid is $thisid"
+ if { [lindex $thisid 1] == $id } {
+   foreach item $entry {
+        if {[lindex $item 0] == "Project" } {
+            set currentProject [lindex $item 1]
+        }
+        if {[lindex $item 0] == "Title" } {
+             set currentActionTitle [lindex $item 1]
+        }
+        }
+ }
+}
+
+
+}
+
 proc actNewState { actid newstate oldstate actnote winname } {
 global allact allactstate
 
@@ -1894,6 +1955,23 @@ if { $currentAction == "" } {
  return
  }
 set a $currentAction
+# if the current state of the action is Periodic then do not set its
+# state to Completed, just set the Completed-date and refresh
+# Period Actions view
+
+
+set thisact [actionFromActid $a]
+
+foreach item $thisact {
+#	puts "item is $item"
+	if { [lindex $item 0] == "Status" && [ lindex $item 1] == "Periodic" } {
+#		puts "This action is Periodic"
+		completePeriodicAction $a
+		return
+	}
+}
+#  puts "This action is not periodic"
+
 donext ""
 actNewState $a Completed Active "" ""
 getactiveactions
@@ -2039,3 +2117,181 @@ foreach action $allact {
 
 }
 
+proc completePeriodicAction { actid } {
+global allact allactstate
+
+  set now [clock format [clock seconds] -format "%Y-%m-%d %H:%M"]
+
+set idx [tag findval $allact Id $actid]
+ if { $idx == -1 } {
+   error "Update_subtasks called for non-existant action $actid"
+   return }
+
+  set entry [lindex $allact $idx]
+
+  tag setorreplace entry Completed-date $now
+
+  set allact [lreplace $allact $idx $idx $entry]
+  set allactstate modified
+  writeallact
+
+ donext ""
+
+ displayPeriodicActions
+
+}
+
+
+proc displayPeriodicActions {} {
+# Display all the active periodic actions in their own window
+global allact debug
+
+# Find out if we have any to display
+foreach action $allact {
+ foreach item $action {
+   if {( [lindex $item 0] == "Status" ) && ([lindex $item 1] == "Periodic" )} {
+# need to check if it has already been done - i.e. Completed during this period
+# Note that there will be a Period field, and that Period could be Period: Daily
+#  or even Period: Daily 15
+#  which will work in a similar way to Active-After
+       set iscompleted 0
+       set period "Daily"
+       set periodval 0
+# Check for a Period
+       foreach i $action {
+		   if { [lindex $i 0] == "Period" } {
+			   set periodstr [lindex $i 1]
+			   set periodlist [split $periodstr]
+			   set period [lindex $periodlist 0]
+			   if {[ llength $periodlist] > 1 } {
+				   set periodval [lindex $periodlist 1]
+			   }
+		   }
+	   }
+# Check for a Completed-date - if there is not one, then it cant be completed
+       foreach i $action {
+         if { [lindex $i 0] == "Completed-date" } {
+             set cdate [lindex $i 1]
+             if { $period == "Daily" } {
+               set PeriodStart "[clock format [clock scan $periodval -format %H] -format %Y-%m-%d] 00:00"
+		       } elseif { $period == "Weekly" } {
+				   if {$periodval == 0 } { set periodval 1 }
+#				   set PeriodStart "[clock format [clock scan $periodval -format %u ] -format %Y-%m-%d] 00:00"
+#                  set PeriodStart "[clock format [clock scan { -1 week + 6 days } ] -format %Y-%m-%d] 00:00"
+                  #  if we are after the day in the week indicated in periodval then check from this week, otherwise check from last week
+                  if { [clock format [ clock seconds ] -format %u ] >= $periodval } {
+#					  puts "Checking from this week"
+					  set PeriodStart "[clock format [clock scan $periodval -format %u ] -format %Y-%m-%d] 00:00"
+				  } else {
+#					  puts "Checking from last week"
+                      set PeriodStart "[clock format [clock scan $periodval -format %u -base [clock scan "last week"] ] -format %Y-%m-%d] 00:00"
+				  }
+			   } elseif { $period == "Monthly" } {
+				   if {$periodval == 0 } { set periodval 1 }
+				   if { [clock format [ clock seconds ] -format %d ] >= $periodval } {
+				       set PeriodStart "[clock format [clock scan $periodval -format %d  ] -format %Y-%m-%d] 00:00"
+				   } else {
+					   set PeriodStart "[clock format [clock scan $periodval -format %d -base [clock scan "last month"] ] -format %Y-%m-%d] 00:00"
+				   }
+			   } elseif { $period == "Yearly" } {
+				   if {$periodval == 0 } { set periodval 1 }
+				   if { [clock format [ clock seconds ] -format %j ] >= $periodval } {
+				      set PeriodStart "[clock format [clock scan $periodval -format %j ] -format %Y-%m-%d] 00:00"
+				  } else {
+					  set PeriodStart "[clock format [clock scan $periodval -format %j -base [clock scan "last year"] ] -format %Y-%m-%d] 00:00"
+				  }
+					     				   
+			   } else {
+				   puts "Invalid period type - set to Daily"
+				   set period = "Daily"
+				   set PeriodStart "[clock format [clock seconds] -format %Y-%m-%d] 00:00"
+			   }
+			 if { $debug > 1 } {
+                puts "Completed $cdate - PeriodStart $PeriodStart"
+			}
+             if { [clock scan $cdate -format "%Y-%m-%d %H:%M"] > [clock scan $PeriodStart -format "%Y-%m-%d %H:%M"] } {
+                    if { $debug > 1 } { puts "Is already completed for this period" }
+                      set iscompleted 1
+                      }
+
+             }
+
+       }
+        
+# but for now ..
+        if { ! $iscompleted } {
+	    lappend periodicActions $action
+            }
+        # 
+	}
+   }
+}
+
+if {[info exists periodicActions]} {
+
+   # We may be being called when the window already exists
+   if { ! [winfo exists .periodicActions ] } {
+       toplevel .periodicActions
+       wm title .periodicActions "Periodic Actions"
+
+        } else {
+        # If the window exists, get rid of the body - it will be recreated
+
+        destroy .periodicActions.body
+        }
+   frame .periodicActions.body
+
+   set i 1
+   foreach action $periodicActions {
+     foreach item $action {
+           if {( [lindex $item 0] == "Title" ) } {
+                set actionTitle [lindex $item 1]
+               }
+           if {( [lindex $item 0] == "Id" ) } {
+                set actionId [lindex $item 1]
+               } 
+           }
+          
+     frame .periodicActions.body.i$i
+
+     button .periodicActions.body.i$i.title -text $actionTitle -command "setcurrentPeriodicAction $actionId"
+     button .periodicActions.body.i$i.done -text "Done" -command "completePeriodicAction $actionId"
+     
+     pack .periodicActions.body.i$i.title .periodicActions.body.i$i.done -in .periodicActions.body.i$i -side left
+
+     pack .periodicActions.body.i$i -in .periodicActions.body
+     incr i
+    }
+    pack .periodicActions.body -side top
+
+    if { ! [winfo exists .periodicActions.bot] } {
+        frame .periodicActions.bot
+        button .periodicActions.bot.ok -text OK -command {doCancel .periodicActions}
+        pack .periodicActions.bot.ok -in .periodicActions.bot
+        pack .periodicActions.bot -side bottom
+    }
+
+    tkwait window .periodicActions
+
+   } else {
+ #    puts "There are no actions to display - check to see if the window should be destroyed"
+
+     if { [ winfo exists .periodicActions] } { destroy .periodicActions }
+
+     }
+   
+
+}
+
+# Action utility functions
+
+proc actionFromActid { actid } {
+	global allact
+	
+set idx [tag findval $allact Id $actid]
+ if { $idx == -1 } {
+   error "actionFromActid called for non-existant action $actid"
+   return }
+
+  return [lindex $allact $idx]
+}
